#!/bin/sh

/bin/cat > /tmp/oxibackup_installation_wizard.php <<'EOF'
<?php
$hostname = gethostname();
echo  <<<PHPEOF
[
EOF

if [ "$SYNOPKG_PKG_STATUS" = "INSTALL" ]
then
    # Check if the machine is already registered
    if [ -f "/opt/oxibackup/config/auth.conf" ] || [ -f "/root/.oxibackup/config/auth.conf" ]
    then
        /bin/cat >> /tmp/oxibackup_installation_wizard.php <<'EOF'
{
    "step_title": "Existing configuration",
    "items": [{
        "type": "multiselect",
        "desc": "It seems that this machine already has an Oxibox configuration. Please confirm that this configuration can be overwritten before you can continue.",
        "subitems": [{
            "key": "oxibox_erase_config",
            "desc": "Overwrite existing configuration and continue",
            "defaultValue": false,
            "validator": {
                "fn": "{var v=arguments[0]; if (!v) return 'You must confirm this operation to continue'; return true;}"
            }
        }]
    }]
},
EOF
    fi

    /bin/cat >> /tmp/oxibackup_installation_wizard.php <<'EOF'
{
    "step_title": "Register your NAS on Oxibox services",
    "items": [{
        "type": "textfield",
        "subitems": [{
            "key": "oxibox_login",
            "desc": "Oxibox account login",
            "invalidText": "Invalid user name",
            "blankText": "Please enter your Oxibox account login",
            "minLength": 1,
            "maxLength": 45,
            "validator": {
                "allowBlank": false,
                "regex": {
                    "expr": "/^[a-z0-9_-]{1,45}$/",
                    "errorText": "Invalid user name"
                }
            }
        }]
    },{
        "type": "password",
        "subitems": [{
            "key": "oxibox_password",
            "desc": "Oxibox account password",
            "invalidText": "Invalid password",
            "blankText": "Please enter your Oxibox account password",
            "minLength": 8,
            "maxLength": 50,
            "validator": {
                "allowBlank": false,
                "regex": {
                    "expr": "/^.{8,50}$/",
                    "errorText": "Invalid password"
                }
            }
        }]
    },{
        "type": "textfield",
        "desc": "Choose a name for your machine or keep the existing host name.",
        "subitems": [{
            "key": "oxibox_hostname",
            "desc": "Machine name",
            "defaultValue": "$hostname",
            "invalidText": "Invalid machine name",
            "blankText": "Please enter a name for your machine",
            "minLength": 2,
            "maxLength": 45,
            "validator": {
                "allowBlank": false,
                "regex": {
                    "expr": "/^[A-Za-z0-9][A-Za-z0-9-_. #]{0,43}[A-Za-z0-9]$/",
                    "errorText": "Invalid machine name"
                }
            }
        }]
    }]
}
EOF
fi

/bin/cat >> /tmp/oxibackup_installation_wizard.php <<'EOF'
]
PHPEOF;
?>
EOF

/usr/bin/php -n /tmp/oxibackup_installation_wizard.php > "$SYNOPKG_TEMP_LOGFILE"
rm /tmp/oxibackup_installation_wizard.php

exit 0
